@@ -42,6 +42,7 @@ class Client:
         self._handshake_data_cb = None
         self._sock = None
         self._running = True
+        self._connected = False
 
     async def setup(self, cbs=None, handshake_cb=None):
         await self._connect()
@@ -73,8 +74,7 @@ class Client:
         return True
 
     async def _connect(self):
-        connected = False
-        while not connected and self._running:
+        while not self._connected and self._running:
             logging.info("Trying to connect")
             try:
                 self._sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
@@ -85,7 +85,7 @@ class Client:
                 await asyncio.sleep(5)
             else:
                 logging.info("Connected")
-                connected = True
+                self._connected = True
                 fcntl.fcntl(self._sock, fcntl.F_SETFL, os.O_NONBLOCK)
 
     async def run(self):
@@ -159,6 +159,8 @@ class Client:
         self._sock.send(header + data)
 
     async def send_message(self, body, message_type, use_qpack=True):
+        if not self._connected:
+            return False
         if use_qpack:
             body = qpack.packb(body)
         await self._send_message(len(body), message_type, body)
